#!/bin/bash
set -e
[ $# -ne 2 ] && { echo "Usage: run-basic.sh DOCKER_DIR JAR_FILENAME"; exit 1; }

DOCKER_DIR=/vagrant/$1
JAR_FILE=$2

DEBUG_PORT=$(cat $DOCKER_DIR/DEBUG_PORT.txt)

NODE_ID=$(ip address show eth0 | grep 'inet ' | sed -e 's/^.*inet //' -e 's/\/.*$//')

MODULE_NAME=$(cat $DOCKER_DIR/ModuleDescriptor.json | grep -m1 "\"id\"" | sed -e 's/^.*"id": "\([^"]*\)".*/\1/')

MODULE_PREFIX=$(echo $MODULE_NAME | sed -n -e 's/\(.*\)-\([0-9]\+\.[0-9]\+\.[0-9]\+\).*/\1/p')

okapi_url=http://localhost:9130/_/proxy/modules

OLD_MODULE_NAME=$(curl -X GET -D - -w '\n' ${okapi_url} |  grep "$MODULE_PREFIX-[0-9]\+\.[0-9]\+\.[0-9]\+" | sed -e 's/^.*"id" : "//' -e 's/",\r*\n*//')

if [[ $(echo "$OLD_MODULE_NAME" | wc -l) -ne 1 ]]; then
  echo "Expected to find exactly one matching old module, instead found $OLD_MODULE_NAME"
  read -p "Please enter module name that should be replaced: "  OLD_MODULE_NAME
fi

echo "Old module to replace: $OLD_MODULE_NAME"

#If old module name contains new module name then versions are the same and we need to append another number to new module name
#For example if old version is mod-circulation-16.7.0-SNAPSHOT.155 then new version should be set to mod-circulation-16.7.0-SNAPSHOT.156
if [[ $OLD_MODULE_NAME == $MODULE_NAME* ]]; then
  OLD_SNAPSHOT_VERSION=$(echo $OLD_MODULE_NAME | grep -o -E "\.([0-9]*)$" | cut -c 2-)
  NEW_SNAPSHOT_VERSION=$(($OLD_SNAPSHOT_VERSION+1))
  sed -i -e "s/${MODULE_NAME}/${MODULE_NAME}.${NEW_SNAPSHOT_VERSION}/g" ${DOCKER_DIR}/ModuleDescriptor.json
  MODULE_NAME=$MODULE_NAME.$NEW_SNAPSHOT_VERSION
fi
echo "New module name $MODULE_NAME"

IMAGE_NAME=docker.ci.folio.org/$MODULE_PREFIX
docker build -t ${IMAGE_NAME} ${DOCKER_DIR} --build-arg DEBUG_PORT=${DEBUG_PORT} --build-arg VERTICLE_FILE=${JAR_FILE}

#Replace tokens with values in DeploymentDescriptor
cp -v ${DOCKER_DIR}/docker-DeploymentDescriptor.json /tmp/docker-DeploymentDescriptor.json
sed -i -e "s/{{MODULE_NAME}}/${MODULE_NAME}/g" -e "s/{{NODE_ID}}/${NODE_ID}/g" -e "s/{{IMAGE_NAME}}/${MODULE_PREFIX}/g" -e "s/{{DEBUG_PORT}}/${DEBUG_PORT}/g" /tmp/docker-DeploymentDescriptor.json

#Undeploy old module to release ports
echo "Undeploying old module $OLD_MODULE_NAME"
okapi_url=http://localhost:9130/_/discovery/modules/${OLD_MODULE_NAME}
curl -X DELETE -D - -w '\n' ${okapi_url}
#Create and deploy new module
echo "Send module descriptor for new module $MODULE_NAME"
curl -X POST -D - -w '\n' -H "Content-type: application/json" -d @${DOCKER_DIR}/ModuleDescriptor.json http://localhost:9130/_/proxy/modules
echo "Send deployment descriptor for new module"
curl -X POST -D - -w '\n' -H "Content-type: application/json" -d @/tmp/docker-DeploymentDescriptor.json http://localhost:9130/_/discovery/modules

#Switch diku tenant to new module
echo "Update tenant"
curl --retry 5 --retry-delay 10 -X POST -D - -w '\n' -H "Content-type: application/json" http://localhost:9130/_/proxy/tenants/diku/upgrade

#Delete old module
echo "Unassign module $OLD_MODULE_NAME"
okapi_url=http://localhost:9130/_/proxy/tenants/diku/modules/${OLD_MODULE_NAME}
curl -X DELETE -D - -w '\n' ${okapi_url}

echo "Delete module $OLD_MODULE_NAME"
okapi_url=http://localhost:9130/_/proxy/modules/${OLD_MODULE_NAME}
curl -X DELETE -D - -w '\n' ${okapi_url}
